/*
 * Copyright 2024 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package androidx.compose.material.icons.twotone

import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.materialIcon
import androidx.compose.material.icons.materialPath
import androidx.compose.ui.graphics.vector.ImageVector

public val Icons.TwoTone.Face2: ImageVector
    get() {
        if (_face2 != null) {
            return _face2!!
        }
        _face2 = materialIcon(name = "TwoTone.Face2") {
            materialPath(fillAlpha = 0.3f, strokeAlpha = 0.3f) {
                moveTo(6.02f, 5.0f)
                curveTo(6.01f, 5.0f, 6.01f, 5.0f, 6.0f, 5.0f)
                curveTo(3.79f, 5.0f, 2.0f, 6.79f, 2.0f, 9.0f)
                curveToRelative(0.0f, 0.55f, 0.12f, 1.07f, 0.32f, 1.54f)
                curveTo(2.89f, 8.29f, 4.22f, 6.35f, 6.02f, 5.0f)
                close()
            }
            materialPath(fillAlpha = 0.3f, strokeAlpha = 0.3f) {
                moveTo(15.1f, 3.5f)
                curveTo(14.36f, 2.59f, 13.25f, 2.0f, 12.0f, 2.0f)
                reflectiveCurveTo(9.64f, 2.59f, 8.9f, 3.5f)
                curveTo(9.88f, 3.18f, 10.92f, 3.0f, 12.0f, 3.0f)
                reflectiveCurveTo(14.12f, 3.18f, 15.1f, 3.5f)
                close()
            }
            materialPath(fillAlpha = 0.3f, strokeAlpha = 0.3f) {
                moveTo(12.0f, 5.31f)
                curveToRelative(0.0f, 2.24f, 1.82f, 4.06f, 4.06f, 4.06f)
                curveToRelative(0.93f, 0.0f, 1.82f, -0.32f, 2.53f, -0.89f)
                curveTo(17.16f, 6.39f, 14.75f, 5.01f, 12.03f, 5.0f)
                curveTo(12.02f, 5.11f, 12.0f, 5.21f, 12.0f, 5.31f)
                close()
            }
            materialPath(fillAlpha = 0.3f, strokeAlpha = 0.3f) {
                moveTo(2.5f, 16.12f)
                curveTo(2.19f, 16.68f, 2.0f, 17.31f, 2.0f, 18.0f)
                curveToRelative(0.0f, 2.21f, 1.79f, 4.0f, 4.0f, 4.0f)
                curveToRelative(0.44f, 0.0f, 0.85f, -0.07f, 1.25f, -0.2f)
                curveTo(5.02f, 20.59f, 3.31f, 18.56f, 2.5f, 16.12f)
                close()
            }
            materialPath(fillAlpha = 0.3f, strokeAlpha = 0.3f) {
                moveTo(21.68f, 10.54f)
                curveTo(21.88f, 10.07f, 22.0f, 9.55f, 22.0f, 9.0f)
                curveToRelative(0.0f, -2.21f, -1.79f, -4.0f, -4.0f, -4.0f)
                curveToRelative(-0.01f, 0.0f, -0.01f, 0.0f, -0.02f, 0.0f)
                curveTo(19.78f, 6.35f, 21.11f, 8.29f, 21.68f, 10.54f)
                close()
            }
            materialPath(fillAlpha = 0.3f, strokeAlpha = 0.3f) {
                moveTo(16.75f, 21.8f)
                curveTo(17.15f, 21.93f, 17.56f, 22.0f, 18.0f, 22.0f)
                curveToRelative(2.21f, 0.0f, 4.0f, -1.79f, 4.0f, -4.0f)
                curveToRelative(0.0f, -0.69f, -0.19f, -1.32f, -0.5f, -1.88f)
                curveTo(20.69f, 18.56f, 18.98f, 20.59f, 16.75f, 21.8f)
                close()
            }
            materialPath {
                moveTo(21.97f, 13.52f)
                curveToRelative(0.0f, -0.01f, 0.0f, -0.02f, 0.0f, -0.04f)
                curveTo(23.21f, 12.38f, 24.0f, 10.78f, 24.0f, 9.0f)
                curveToRelative(0.0f, -3.31f, -2.69f, -6.0f, -6.0f, -6.0f)
                curveToRelative(-0.26f, 0.0f, -0.52f, 0.02f, -0.78f, 0.06f)
                curveTo(16.19f, 1.23f, 14.24f, 0.0f, 12.0f, 0.0f)
                reflectiveCurveTo(7.81f, 1.23f, 6.78f, 3.06f)
                curveTo(6.52f, 3.02f, 6.26f, 3.0f, 6.0f, 3.0f)
                curveTo(2.69f, 3.0f, 0.0f, 5.69f, 0.0f, 9.0f)
                curveToRelative(0.0f, 1.78f, 0.79f, 3.38f, 2.02f, 4.48f)
                curveToRelative(0.0f, 0.01f, 0.0f, 0.02f, 0.0f, 0.04f)
                curveTo(0.79f, 14.62f, 0.0f, 16.22f, 0.0f, 18.0f)
                curveToRelative(0.0f, 3.31f, 2.69f, 6.0f, 6.0f, 6.0f)
                curveToRelative(1.39f, 0.0f, 2.67f, -0.48f, 3.69f, -1.28f)
                curveTo(10.43f, 22.9f, 11.2f, 23.0f, 12.0f, 23.0f)
                reflectiveCurveToRelative(1.57f, -0.1f, 2.31f, -0.28f)
                curveTo(15.33f, 23.52f, 16.61f, 24.0f, 18.0f, 24.0f)
                curveToRelative(3.31f, 0.0f, 6.0f, -2.69f, 6.0f, -6.0f)
                curveTo(24.0f, 16.22f, 23.21f, 14.62f, 21.97f, 13.52f)
                close()
                moveTo(18.0f, 5.0f)
                curveToRelative(2.21f, 0.0f, 4.0f, 1.79f, 4.0f, 4.0f)
                curveToRelative(0.0f, 0.55f, -0.12f, 1.07f, -0.32f, 1.54f)
                curveToRelative(-0.57f, -2.25f, -1.9f, -4.19f, -3.7f, -5.54f)
                curveTo(17.99f, 5.0f, 17.99f, 5.0f, 18.0f, 5.0f)
                close()
                moveTo(18.6f, 8.48f)
                curveToRelative(-0.71f, 0.57f, -1.6f, 0.89f, -2.53f, 0.89f)
                curveTo(13.82f, 9.38f, 12.0f, 7.55f, 12.0f, 5.31f)
                curveToRelative(0.0f, -0.1f, 0.02f, -0.21f, 0.03f, -0.31f)
                curveTo(14.75f, 5.01f, 17.16f, 6.39f, 18.6f, 8.48f)
                close()
                moveTo(12.0f, 2.0f)
                curveToRelative(1.25f, 0.0f, 2.36f, 0.59f, 3.1f, 1.5f)
                curveTo(14.12f, 3.18f, 13.08f, 3.0f, 12.0f, 3.0f)
                reflectiveCurveTo(9.88f, 3.18f, 8.9f, 3.5f)
                curveTo(9.64f, 2.59f, 10.75f, 2.0f, 12.0f, 2.0f)
                close()
                moveTo(2.0f, 9.0f)
                curveToRelative(0.0f, -2.21f, 1.79f, -4.0f, 4.0f, -4.0f)
                curveToRelative(0.01f, 0.0f, 0.01f, 0.0f, 0.02f, 0.0f)
                curveToRelative(-1.8f, 1.35f, -3.13f, 3.29f, -3.7f, 5.54f)
                curveTo(2.12f, 10.07f, 2.0f, 9.55f, 2.0f, 9.0f)
                close()
                moveTo(6.0f, 22.0f)
                curveToRelative(-2.21f, 0.0f, -4.0f, -1.79f, -4.0f, -4.0f)
                curveToRelative(0.0f, -0.69f, 0.19f, -1.32f, 0.5f, -1.88f)
                curveToRelative(0.8f, 2.44f, 2.52f, 4.47f, 4.74f, 5.68f)
                curveTo(6.85f, 21.93f, 6.44f, 22.0f, 6.0f, 22.0f)
                close()
                moveTo(12.0f, 21.0f)
                curveToRelative(-4.41f, 0.0f, -8.0f, -3.59f, -8.0f, -8.0f)
                curveToRelative(0.0f, -3.72f, 2.56f, -6.85f, 6.0f, -7.74f)
                curveToRelative(0.0f, 0.02f, 0.0f, 0.03f, 0.0f, 0.05f)
                curveToRelative(0.0f, 3.34f, 2.72f, 6.06f, 6.06f, 6.06f)
                curveToRelative(1.26f, 0.0f, 2.45f, -0.39f, 3.45f, -1.09f)
                curveTo(19.82f, 11.14f, 20.0f, 12.05f, 20.0f, 13.0f)
                curveTo(20.0f, 17.41f, 16.41f, 21.0f, 12.0f, 21.0f)
                close()
                moveTo(18.0f, 22.0f)
                curveToRelative(-0.44f, 0.0f, -0.85f, -0.07f, -1.25f, -0.2f)
                curveToRelative(2.23f, -1.21f, 3.94f, -3.24f, 4.74f, -5.68f)
                curveToRelative(0.31f, 0.56f, 0.5f, 1.2f, 0.5f, 1.88f)
                curveTo(22.0f, 20.21f, 20.21f, 22.0f, 18.0f, 22.0f)
                close()
            }
            materialPath {
                moveTo(9.0f, 14.0f)
                moveToRelative(-1.25f, 0.0f)
                arcToRelative(1.25f, 1.25f, 0.0f, true, true, 2.5f, 0.0f)
                arcToRelative(1.25f, 1.25f, 0.0f, true, true, -2.5f, 0.0f)
            }
            materialPath {
                moveTo(15.0f, 14.0f)
                moveToRelative(-1.25f, 0.0f)
                arcToRelative(1.25f, 1.25f, 0.0f, true, true, 2.5f, 0.0f)
                arcToRelative(1.25f, 1.25f, 0.0f, true, true, -2.5f, 0.0f)
            }
        }
        return _face2!!
    }

private var _face2: ImageVector? = null
